import { FC, Fragment, PropsWithChildren, useEffect, useState } from 'react'
import { Disclosure, Menu, Transition } from '@headlessui/react'
import { Bars3Icon, BellIcon, XMarkIcon } from '@heroicons/react/24/outline'
import { UserCircleIcon, MagnifyingGlassIcon } from '@heroicons/react/24/solid'
import { User } from '@/types/user'
import NavMenu from './NavMenu'
import BasicField from '../form/BasicField'
import useDebounce from '@/hooks/useDebounce'
import UserSearch from '../form/UserSearch'

const navigation = [
  { name: 'My Feed', href: '/feed', current: true }
]
const userNavigation = [
  { name: 'Your Profile', href: '/profile' },
  { name: 'Search', href: '/search'},
  { name: 'Sign out', href: '/signOut' },
]

function classNames(...classes: any) {
  return classes.filter(Boolean).join(' ')
}

type NavBarProps = {
  user: User | undefined;
}

const NavBar: FC<PropsWithChildren<NavBarProps>> = ({
  children,
  user
}) =>  { 


  return (
    <>
      <div className="min-h-full min-w-full">
        <Disclosure as="nav" className="bg-c-pink fixed w-full z-10">
          {({ open }) => (
            <>
              <div className="mx-auto max-w-7xl px-4 sm:px-6 lg:px-8">
                <div className={`flex h-16 items-center justify-between`}>

                  {user !== undefined &&
                    <div className="flex items-center">
                      <div className="hidden md:block">
                        <div className="flex items-baseline space-x-4">
                          {navigation.map((item) => (
                            <a
                              key={item.name}
                              href={item.href}
                              className={classNames(
                                item.current
                                  ? 'bg-c-pink text-white'
                                  : 'text-c-pink hover:bg-c-pink hover:text-white',
                                'rounded-md px-3 py-2 text-sm font-medium'
                              )}
                              aria-current={item.current ? 'page' : undefined}
                            >
                              {item.name}
                            </a>
                          ))}
                        </div>
                      </div>
                    </div>
                  }
                  <div>
                    <h1 className="text-2xl font-bold tracking-tight text-c-green">Daily</h1>
                  </div>
                  
                  {user !== undefined && 
                    <div className="hidden md:block">
                      <div className="flex items-center">

                        <NavMenu icon={<MagnifyingGlassIcon className="h-6 w-6" aria-hidden="true"/>} width={"w-64"}>
                          <UserSearch />
                        </NavMenu>

                        <button
                          type="button"
                          className="ml-3 rounded-full bg-c-pink p-1 text-white hover:text-white focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink"
                        >
                          <span className="sr-only">View notifications</span>
                          <BellIcon className="h-6 w-6" aria-hidden="true" />
                        </button>

                        {/* Profile dropdown */}
                        <Menu as="div" className="relative ml-3">
                          <div>
                            <Menu.Button className="flex max-w-xs items-center rounded-full bg-white text-sm focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink">
                              <span className="sr-only">Open user menu</span>
                              {user && user.profile.length > 0 &&
                                <img className="h-8 w-8 rounded-full" src={user.profile} alt="" />
                              }

                              {user && user.profile.length === 0 &&
                                <UserCircleIcon className='h-8 w-8 rounded-full text-gray-300 flex items-center justify-center'>{user.username[0]}</UserCircleIcon>
                              }
                              
                            </Menu.Button>
                          </div>
                          <Transition
                            as={Fragment}
                            enter="transition ease-out duration-100"
                            enterFrom="transform opacity-0 scale-95"
                            enterTo="transform opacity-100 scale-100"
                            leave="transition ease-in duration-75"
                            leaveFrom="transform opacity-100 scale-100"
                            leaveTo="transform opacity-0 scale-95"
                          >
                            <Menu.Items className="absolute right-0 z-10 mt-2 w-48 origin-top-right rounded-md bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none">
                              <div className='w-full border-b'>
                                <p className='block px-4 py-2 text-sm text-gray-700 font-bold'>{`Hi, ${user?.firstName || user?.username}`}</p>
                              </div>
                              {userNavigation.map((item) => (
                                <Menu.Item key={item.name}>
                                  {({ active }) => (
                                    <a
                                      href={item.href}
                                      className={classNames(
                                        active ? 'bg-gray-100' : '',
                                        'block px-4 py-2 text-sm text-gray-700'
                                      )}
                                    >
                                      {item.name}
                                    </a>
                                  )}
                                </Menu.Item>
                              ))}
                            </Menu.Items>
                          </Transition>
                        </Menu>
                      </div>
                    </div>
                  }
                  
                  {user !== undefined && 
                    <div className="-mr-2 flex md:hidden">
                      {/* Mobile menu button */}
                      <Disclosure.Button className="inline-flex items-center justify-center rounded-md bg-white p-2 text-c-pink hover:bg-c-pink hover:text-white focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink">
                        <span className="sr-only">Open main menu</span>
                        {open ? (
                          <XMarkIcon className="block h-6 w-6" aria-hidden="true" />
                        ) : (
                          <Bars3Icon className="block h-6 w-6" aria-hidden="true" />
                        )}
                      </Disclosure.Button>
                    </div>
                  }
                </div>
              </div>

              <Disclosure.Panel className="md:hidden">
                <div className="space-y-1 px-2 pt-2 pb-3 sm:px-3 bg-c-pink">
                  {navigation.map((item) => (
                    <Disclosure.Button
                      key={item.name}
                      as="a"
                      href={item.href}
                      className={classNames(
                        item.current ? 'bg-c-pink text-white' : 'text-gray-300 hover:bg-gray-700 hover:text-white',
                        'block rounded-md px-3 py-2 text-base font-medium'
                      )}
                      aria-current={item.current ? 'page' : undefined}
                    >
                      {item.name}
                    </Disclosure.Button>
                  ))}
                </div>
                <div className=" pt-4 pb-3 bg-c-pink ">
                  <div className="flex items-center px-5 bg-white mx-2 py-2 rounded-md">
                    <div className="flex-shrink-0">
                      {user && user.profile.length > 0 && 
                        <img className="h-10 w-10 rounded-full" src={user?.profile} alt="" />
                      }

                      {user && user.profile.length === 0 &&
                        <UserCircleIcon className='h-10 w-10 rounded-full text-gray-300 flex items-center justify-center'>{user.username[0]}</UserCircleIcon>
                      }
                      
                    </div>
                    <div className="ml-3">
                      {user?.firstName && <div className="text-base font-medium leading-none text-grey-600">{`${user?.firstName || ""} ${user?.lastName || ""}`}</div>}
                      <div className="text-sm font-medium leading-none text-gray-400">{`@${user?.username}`}</div>
                    </div>
                    <button
                      type="button"
                      className="ml-auto flex-shrink-0 rounded-full bg-c-pink p-1 text-white hover:text-c-pink hover:bg-white focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink"
                    >
                      <span className="sr-only">View notifications</span>
                      <BellIcon className="h-6 w-6" aria-hidden="true" />
                    </button>
                  </div>
                  <div className="mt-1 space-y-1 px-2">
                    {userNavigation.map((item) => (
                      <Disclosure.Button
                        key={item.name}
                        as="a"
                        href={item.href}
                        className="block bg-white rounded-md px-3 py-2 text-base font-medium text-c-pink hover:bg-pink-300 hover:text-green-200"
                      >
                        {item.name}
                      </Disclosure.Button>
                    ))}
                  </div>
                </div>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <main>
          <div className="mx-auto">{children}</div>
        </main>
      </div>
    </>
  )
}

export default NavBar;